Point

Struct Point 

pub struct Point<N: Num = f32>(pub N, pub N);

Tuple Fields

0: N1: N

Implementations

Source

impl<N: Num> Point<N>

pub fn new_zero_value() -> Self

pub fn new_from_angle(angle: f32, hypot: f32) -> Self

pub fn move_from_angle(self, angle: f32, hypot: f32) -> Self

pub fn x(&self) -> N

pub fn y(&self) -> N

pub fn move_x(&mut self, x: N)

pub fn move_y(&mut self, y: N)

pub fn set_x(&mut self, x: N)

pub fn set_y(&mut self, y: N)

pub fn line_to(self, other: Self) -> Line<N>

pub fn rect_to(self, other: Self) -> Rect<N>

pub fn distance_to(self, other: Self) -> Size<N>

pub fn direction_to(self, other: Self) -> Size<f32>

pub fn to<T: Num + From<N>>(&self) -> Point<T>

This is to allow creating a new Point, which wraps a different number type.

For example Point(1u8, 2u8)::to::<u32>() creates a Point(1u32, 2u32).

pub fn abs(&self) -> Self

pub fn min(self, other: Self) -> Self

pub fn min_x(self, other_x: N) -> Self

pub fn min_y(self, other_y: N) -> Self

pub fn max(self, other: Self) -> Self

pub fn max_x(self, other_x: N) -> Self

pub fn max_y(self, other_y: N) -> Self

pub fn hypot_to(self, other: Point<N>) -> N

pub fn rotate_around_point(self, angle: f32, other: Self) -> Self

pub fn rotate_around_zero(self, rotation: f32) -> Self

pub fn angle_to(self, other: Self) -> f32

pub fn interpolate_to(self, other: Point<N>, n: N) -> Point<N>

pub fn to_size(self) -> Size<N>

pub fn swizzle_xy(self) -> Self

Returns a copy of this point (with no changes).

pub fn swizzle_yx(self) -> Self

Returns a copy of this Point with the x and y values swapped.

pub fn swizzle_xx(self) -> Self

pub fn swizzle_yy(self) -> Self

pub fn swizzle_0x(self) -> Self

pub fn swizzle_0y(self) -> Self

pub fn swizzle_x0(self) -> Self

pub fn swizzle_y0(self) -> Self

pub fn into_slice(self) -> [N; 2]

Source

impl<N: Num + ToSignedClamped> Point<N>
where <N as ToSignedClamped>::Output: Signed,

pub fn to_signed_clamped(self) -> Point<<N as ToSignedClamped>::Output>

pub fn step_direction_to( self, other: Point<N>, ) -> Point<<N as ToSignedClamped>::Output>

Source

impl<N: Num + Signed> Point<N>

pub fn sign(&self) -> Self

pub fn min_by_abs(self, other: Self) -> Self

pub fn min_x_by_abs(self, other_x: N) -> Self

pub fn min_y_by_abs(self, other_y: N) -> Self

pub fn max_by_abs(self, other: Self) -> Self

pub fn max_x_by_abs(self, other_x: N) -> Self

pub fn max_y_by_abs(self, other_y: N) -> Self

pub fn step(&self) -> Self

pub fn sign_exclusive_dir(&self) -> Self

pub fn flip_x(self) -> Self

pub fn flip_y(self) -> Self

Source

impl Point<f32>

pub fn overlaps(self, Point: Self, xy1: Self, xy2: Self) -> bool

pub fn floor(self) -> Self

pub fn ceil(self) -> Self

pub fn round(self) -> Self

pub fn cossin(self, angle: f32) -> Self